AircraftAPIApi class

Constructors

AircraftAPIApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAircraft(AircraftSearchByEnum searchBy, String searchParam, {bool? withImage, bool? withRegistrations}) Future<AircraftContract?>
Single aircraft (by tail-number, Mode-S or ID) TIER 1
getAircraftImageByRegistration(String reg) Future<ResourceContract?>
Aircraft image by tail-number (BETA) TIER 2
getAircraftImageByRegistrationWithHttpInfo(String reg) Future<Response>
Aircraft image by tail-number (BETA) TIER 2
getAircraftRegistrations(AircraftSearchByEnum searchBy, String searchParam) Future<List<AircraftRegistrationContract>?>
Single aircraft registration history (by tail-number, Mode-S or ID) TIER 1
getAircraftRegistrationsWithHttpInfo(AircraftSearchByEnum searchBy, String searchParam) Future<Response>
Single aircraft registration history (by tail-number, Mode-S or ID) TIER 1
getAircraftWithHttpInfo(AircraftSearchByEnum searchBy, String searchParam, {bool? withImage, bool? withRegistrations}) Future<Response>
Single aircraft (by tail-number, Mode-S or ID) TIER 1
getAirlineFleet(String airlineCode, int pageSize, {int? pageOffset, bool? withRegistrations}) Future<AircraftContractPagedCollectionContract?>
Airline fleet / Aircraft list by airline code (BETA) TIER 3
getAirlineFleetWithHttpInfo(String airlineCode, int pageSize, {int? pageOffset, bool? withRegistrations}) Future<Response>
Airline fleet / Aircraft list by airline code (BETA) TIER 3
getAllAircraft(AircraftSearchByEnum searchBy, String searchParam, {bool? withImage, bool? withRegistrations}) Future<List<AircraftContract>?>
All aircraft (by tail-number, Mode-S or ID) TIER 1
getAllAircraftWithHttpInfo(AircraftSearchByEnum searchBy, String searchParam, {bool? withImage, bool? withRegistrations}) Future<Response>
All aircraft (by tail-number, Mode-S or ID) TIER 1
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recognizeAircraft(MultipartFile photo) Future<AircraftRecognitionResultContract?>
Aicraft image recognition (BETA) TIER 3
recognizeAircraftWithHttpInfo(MultipartFile photo) Future<Response>
Aicraft image recognition (BETA) TIER 3
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited