getAircraftImageByRegistrationWithHttpInfo method

Future<Response> getAircraftImageByRegistrationWithHttpInfo(
  1. String reg
)

Aircraft image by tail-number (BETA) TIER 2

What is the aircraft photo? Aircraft images are being searched in external sources by certain criteria without any manual intervention. Therefore, false matches may be returned. Only images with licenses approved for commercial use are returned. Please be advised that you may be required to mention author attribution before using the image. Returns: Image data with medium-sized direct image URL and licence approved for commercial use is returned.

Note: This method returns the HTTP Response.

Parameters:

  • String reg (required): Tail-number of the aircraft (full, stripped and any case formats are acceptable).

Implementation

Future<Response> getAircraftImageByRegistrationWithHttpInfo(
  String reg,
) async {
  // ignore: prefer_const_declarations
  final path = r'/aircrafts/reg/{reg}/image/beta'.replaceAll('{reg}', reg);

  // ignore: prefer_final_locals
  Object? postBody;

  final queryParams = <QueryParam>[];
  final headerParams = <String, String>{};
  final formParams = <String, String>{};

  const contentTypes = <String>[];

  return apiClient.invokeAPI(
    path,
    'GET',
    queryParams,
    postBody,
    headerParams,
    formParams,
    contentTypes.isEmpty ? null : contentTypes.first,
  );
}