recognizeAircraft method
Aicraft image recognition (BETA) TIER 3
What aircrafts are depicted on this photo? This endpoint recognizes aircrafts on uploaded image and returns information about all detected aircrafts. It is based on computer vision technology and therefore results may be imprecise. It relies on detecting aircrafts' registrations and, once detected, attempting to match these registration with records in aircrafts database. Returns: Data about found and recognized aircrafts.
Parameters:
MultipartFilephoto (required):
Implementation
Future<AircraftRecognitionResultContract?> recognizeAircraft(
MultipartFile photo,
) async {
final response = await recognizeAircraftWithHttpInfo(
photo,
);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty &&
response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(
await _decodeBodyBytes(response),
'AircraftRecognitionResultContract',
) as AircraftRecognitionResultContract;
}
return null;
}