recognizeAircraftWithHttpInfo method
Aicraft image recognition (BETA) TIER 3
What aircrafts are depicted on this photo? This endpoint recognizes aircrafts on uploaded image and returns information about all detected aircrafts. It is based on computer vision technology and therefore results may be imprecise. It relies on detecting aircrafts' registrations and, once detected, attempting to match these registration with records in aircrafts database. Returns: Data about found and recognized aircrafts.
Note: This method returns the HTTP Response.
Parameters:
MultipartFilephoto (required):
Implementation
Future<Response> recognizeAircraftWithHttpInfo(
MultipartFile photo,
) async {
// ignore: prefer_const_declarations
final path = r'/aircrafts/recognize/beta';
// ignore: prefer_final_locals
Object? postBody;
final queryParams = <QueryParam>[];
final headerParams = <String, String>{};
final formParams = <String, String>{};
const contentTypes = <String>['multipart/form-data'];
bool hasFields = false;
final mp = MultipartRequest('POST', Uri.parse(path));
hasFields = true;
mp.fields[r'photo'] = photo.field;
mp.files.add(photo);
if (hasFields) {
postBody = mp;
}
return apiClient.invokeAPI(
path,
'POST',
queryParams,
postBody,
headerParams,
formParams,
contentTypes.isEmpty ? null : contentTypes.first,
);
}