numRegistrations property

int numRegistrations
getter/setter pair

An aircraft may have a history of past registrations with other airlines or operators. This field represents a total number of registration records known in our database.

Implementation

int numRegistrations;