toString method

  1. @override
String toString()
override

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() =>
    'AircraftContract[id=$id, reg=$reg, active=$active, isFreighter=$isFreighter, verified=$verified, numRegistrations=$numRegistrations, serial=$serial, hexIcao=$hexIcao, airlineName=$airlineName, iataType=$iataType, iataCodeShort=$iataCodeShort, icaoCode=$icaoCode, model=$model, modelCode=$modelCode, numSeats=$numSeats, rolloutDate=$rolloutDate, firstFlightDate=$firstFlightDate, deliveryDate=$deliveryDate, registrationDate=$registrationDate, typeName=$typeName, numEngines=$numEngines, engineType=$engineType, productionLine=$productionLine, ageYears=$ageYears, image=$image, registrations=$registrations]';