AircraftContractImage class

Constructors

AircraftContractImage({required String url, required LicenseType license, String? webUrl, String? author, String? title, String? description, List<String>? htmlAttributions = const []})
Returns a new AircraftContractImage instance.

Properties

author String?
Author name of the resource
getter/setter pair
description String?
Description of the resource
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
htmlAttributions List<String>?
Attributions maintaining copyright, ownership and other legal information adjusted for displaying as HTML. Each element represent one line.
getter/setter pair
license LicenseType
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
Title of the resource
getter/setter pair
url String
URL of the resource
getter/setter pair
webUrl String?
URL of web-page containing the resource
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) AircraftContractImage?
Returns a new AircraftContractImage instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<AircraftContractImage>
mapFromJson(dynamic json) Map<String, AircraftContractImage>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<AircraftContractImage>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.