AircraftContractPagedCollectionContract class

Constructors

AircraftContractPagedCollectionContract({required int totalCount, required int pageOffset, required int pageSize, required bool hasNextPage, required int count, List<AircraftContract> items = const []})
Returns a new AircraftContractPagedCollectionContract instance.

Properties

count int
The number of items in the collection
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
hasNextPage bool
This value is true when collection has more pages
getter/setter pair
items List<AircraftContract>
The collection of items
getter/setter pair
pageOffset int
The offset of the current page of the collection (number of items skipped before this page)
getter/setter pair
pageSize int
Maximum number of items on the current page of the collection (Count cannot be more than this value)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalCount int
The total number of items across all pages
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) AircraftContractPagedCollectionContract?
Returns a new AircraftContractPagedCollectionContract instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<AircraftContractPagedCollectionContract>
mapFromJson(dynamic json) Map<String, AircraftContractPagedCollectionContract>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<AircraftContractPagedCollectionContract>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.