pageOffset property
The offset of the current page of the collection (number of items skipped before this page)
Minimum value: 0 Maximum value: 2147483647
Implementation
int pageOffset;
The offset of the current page of the collection (number of items skipped before this page)
Minimum value: 0 Maximum value: 2147483647
int pageOffset;