pageSize property
Maximum number of items on the current page of the collection (Count cannot be more than this value)
Minimum value: 0 Maximum value: 2147483647
Implementation
int pageSize;
Maximum number of items on the current page of the collection (Count cannot be more than this value)
Minimum value: 0 Maximum value: 2147483647
int pageSize;