AircraftRecognitionResultContract class

Constructors

AircraftRecognitionResultContract({Map<String, AircraftContract> recognized = const {}})
Returns a new AircraftRecognitionResultContract instance.

Properties

hashCode int
The hash code for this object.
no setteroverride
recognized Map<String, AircraftContract>
Object containing aircrafts recognized. Property key is aircraft registration recognized on the media resource. Property value is an object with aircraft data found in database for corresponding registration. If nothing is found, the value will be null.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) AircraftRecognitionResultContract?
Returns a new AircraftRecognitionResultContract instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<AircraftRecognitionResultContract>
mapFromJson(dynamic json) Map<String, AircraftRecognitionResultContract>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<AircraftRecognitionResultContract>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.