AircraftRegistrationContract class

Constructors

AircraftRegistrationContract({required String reg, required bool active, String? hexIcao, String? airlineName, DateTime? registrationDate})
Returns a new AircraftRegistrationContract instance.

Properties

active bool
Indicator if aircraft is operational under this registration
getter/setter pair
airlineName String?
Name of the airline operating the aircraft
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
hexIcao String?
ICAO 24 bit Mode-S hexadecimal transponder address
getter/setter pair
reg String
Tail-number of the aircraft
getter/setter pair
registrationDate DateTime?
Date of assigning current registration
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) AircraftRegistrationContract?
Returns a new AircraftRegistrationContract instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<AircraftRegistrationContract>
mapFromJson(dynamic json) Map<String, AircraftRegistrationContract>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<AircraftRegistrationContract>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.