AircraftSearchByEnum class

Criteria to search aircraft by

Possible values:

  • 0 - Id: ID of the aircraft (as stored in this API)
  • 1 - Reg: Search by aircraft tail-number
  • 2 - Icao24: Search by 24-bit ICAO Mode-S Transponder code

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) AircraftSearchByEnum?
listFromJson(dynamic json, {bool growable = false}) List<AircraftSearchByEnum>

Constants

icao24 → const AircraftSearchByEnum
id → const AircraftSearchByEnum
reg → const AircraftSearchByEnum
values → const List<AircraftSearchByEnum>
List of all possible values in this AircraftSearchByEnum.