AirportAPIApi class

Constructors

AirportAPIApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAirport(AirportCodesByEnum codeType, String code, {bool? withRunways, bool? withTime}) Future<AirportContract?>
Airport by code TIER 1
getAirportRunways(AirportCodesByEnum codeType, String code) Future<List<RunwayContract>?>
Airport runways TIER 1
getAirportRunwaysWithHttpInfo(AirportCodesByEnum codeType, String code) Future<Response>
Airport runways TIER 1
getAirportWithHttpInfo(AirportCodesByEnum codeType, String code, {bool? withRunways, bool? withTime}) Future<Response>
Airport by code TIER 1
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
searchAirportByTerm(String q, {int? limit, bool? withFlightInfoOnly, bool? withSearchByCode}) Future<StringListingAirportContractSearchResultCollectionContract?>
Search airports by free text TIER 2
searchAirportByTermWithHttpInfo(String q, {int? limit, bool? withFlightInfoOnly, bool? withSearchByCode}) Future<Response>
Search airports by free text TIER 2
searchAirportsByIpGeoLocation(String q, int radiusKm, int limit, {bool? withFlightInfoOnly}) Future<GeoCoordinatesContractListingAirportContractSearchResultCollectionContract?>
Search airports by IP address geolocation TIER 2
searchAirportsByIpGeoLocationWithHttpInfo(String q, int radiusKm, int limit, {bool? withFlightInfoOnly}) Future<Response>
Search airports by IP address geolocation TIER 2
searchAirportsByLocation(double lat, double lon, int radiusKm, int limit, {bool? withFlightInfoOnly}) Future<GeoCoordinatesContractListingAirportContractSearchResultCollectionContract?>
Search airports by location TIER 2
searchAirportsByLocationWithHttpInfo(double lat, double lon, int radiusKm, int limit, {bool? withFlightInfoOnly}) Future<Response>
Search airports by location TIER 2
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited