AirportContract class
Constructors
-
AirportContract({required String fullName, required GeoCoordinatesContract location, required Distance elevation, required AirportCountryContract country, required AirportContinentContract continent, required String timeZone, required AirportContractUrls urls, String? icao, String? iata, String? localCode, String? shortName, String? municipalityName, List<
RunwayContract> ? runways = const [], AirportContractCurrentTime? currentTime}) - Returns a new AirportContract instance.
Properties
- continent ↔ AirportContinentContract
-
getter/setter pair
- country ↔ AirportCountryContract
-
getter/setter pair
- currentTime ↔ AirportContractCurrentTime?
-
getter/setter pair
- elevation ↔ Distance
-
getter/setter pair
- fullName ↔ String
-
Full name of the airport (derived from own airport name and municipality name)
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- iata ↔ String?
-
IATA code of the airport
getter/setter pair
- icao ↔ String?
-
ICAO code of the airport
getter/setter pair
- localCode ↔ String?
-
Code of the airport within the local or national codification system
getter/setter pair
- location ↔ GeoCoordinatesContract
-
getter/setter pair
- municipalityName ↔ String?
-
Name of the municipality this airport belongs to
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
runways
↔ List<
RunwayContract> ? -
List of runway information, if requested
getter/setter pair
- shortName ↔ String?
-
Shortened name of the airport
getter/setter pair
- timeZone ↔ String
-
Time zone of the airport in Olson format (e.g. "Europe/Amsterdam")
getter/setter pair
- urls ↔ AirportContractUrls
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → AirportContract? -
Returns a new AirportContract instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< AirportContract> -
mapFromJson(
dynamic json) → Map< String, AirportContract> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< AirportContract> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.