AirportDistanceTimeContract class

Constructors

AirportDistanceTimeContract({required ListingAirportContract from, required ListingAirportContract to, required Distance greatCircleDistance, required String approxFlightTime})
Returns a new AirportDistanceTimeContract instance.

Properties

approxFlightTime String
Approximate flight time based on re-calculation of great circle distance against statistical duration average of multiple flights covered similar distance before.
getter/setter pair
from ListingAirportContract
getter/setter pair
greatCircleDistance Distance
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
to ListingAirportContract
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) AirportDistanceTimeContract?
Returns a new AirportDistanceTimeContract instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<AirportDistanceTimeContract>
mapFromJson(dynamic json) Map<String, AirportDistanceTimeContract>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<AirportDistanceTimeContract>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.