AirportFeedServiceStatusContract class

Constructors

AirportFeedServiceStatusContract({required FeedServiceStatusContract flightSchedulesFeed, required FeedServiceStatusContract liveFlightUpdatesFeed, required FeedServiceStatusContract adsbUpdatesFeed, required FlightDataGeneralAvailabilityContract generalAvailability})
Returns a new AirportFeedServiceStatusContract instance.

Properties

adsbUpdatesFeed FeedServiceStatusContract
getter/setter pair
flightSchedulesFeed FeedServiceStatusContract
getter/setter pair
generalAvailability FlightDataGeneralAvailabilityContract
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
liveFlightUpdatesFeed FeedServiceStatusContract
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) AirportFeedServiceStatusContract?
Returns a new AirportFeedServiceStatusContract instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<AirportFeedServiceStatusContract>
mapFromJson(dynamic json) Map<String, AirportFeedServiceStatusContract>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<AirportFeedServiceStatusContract>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.