AirportFidsContract class

Constructors

AirportFidsContract({List<AirportFlightContract>? departures = const [], List<AirportFlightContract>? arrivals = const []})
Returns a new AirportFidsContract instance.

Properties

arrivals List<AirportFlightContract>?
Arriving flights
getter/setter pair
departures List<AirportFlightContract>?
Departing flights
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) AirportFidsContract?
Returns a new AirportFidsContract instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<AirportFidsContract>
mapFromJson(dynamic json) Map<String, AirportFidsContract>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<AirportFidsContract>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.