AirportLocalTimeContract class
Constructors
- AirportLocalTimeContract({required DateTimeContract time, required String timeZoneId})
- Returns a new AirportLocalTimeContract instance.
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- time ↔ DateTimeContract
-
getter/setter pair
- timeZoneId ↔ String
-
Timezone ID of the airport (Olson format)
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → AirportLocalTimeContract? -
Returns a new AirportLocalTimeContract instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< AirportLocalTimeContract> -
mapFromJson(
dynamic json) → Map< String, AirportLocalTimeContract> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< AirportLocalTimeContract> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.