Azimuth class

Constructors

Azimuth({required double deg, required double rad})
Returns a new Azimuth instance.

Properties

deg double
Angle in degrees (between 0 and 360)
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
rad double
Angle in radians (0 and 2 * Pi)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) Azimuth?
Returns a new Azimuth instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<Azimuth>
mapFromJson(dynamic json) Map<String, Azimuth>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<Azimuth>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.