CloudCover class

Possible values:

  • 0 - Unknown
  • 1 - Clear
  • 2 - Few
  • 3 - Broken
  • 4 - Overcast

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) CloudCover?
listFromJson(dynamic json, {bool growable = false}) List<CloudCover>

Constants

broken → const CloudCover
clear → const CloudCover
few → const CloudCover
overcast → const CloudCover
unknown → const CloudCover
values → const List<CloudCover>
List of all possible values in this CloudCover.