CodeshareStatus class
Flight code-share status
Possible values:
- 0 - Unknown: Code-sharing information is unavailable for this flight. Flight might be operated both by airline owning the flight number as well as by another airliner.
- 1 - IsOperator: Flight is operated by an airline owning the flight number (the same code)
- 2 - IsCodeshared: Flight is code-shared (operated by an airline other than airline owning the flight number)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
dynamic value) → CodeshareStatus? -
listFromJson(
dynamic json, {bool growable = false}) → List< CodeshareStatus>
Constants
- isOperator → const CodeshareStatus
- unknown → const CodeshareStatus
-
values
→ const List<
CodeshareStatus> - List of all possible values in this CodeshareStatus.