DayTime class

Daytime states

Possible values:

  • 0 - Night
  • 1 - TwilightAstronomical
  • 2 - TwilightNautical
  • 3 - TwilightCivil
  • 4 - Day
  • 5 - BlueHour
  • 6 - GoldenHour

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) DayTime?
listFromJson(dynamic json, {bool growable = false}) List<DayTime>

Constants

blueHour → const DayTime
day → const DayTime
goldenHour → const DayTime
night → const DayTime
twilightAstronomical → const DayTime
twilightCivil → const DayTime
twilightNautical → const DayTime
values → const List<DayTime>
List of all possible values in this DayTime.