DelayBracketContract class

Constructors

DelayBracketContract({required int num_, String? delayedFrom, String? delayedTo, double? percentage})
Returns a new DelayBracketContract instance.

Properties

delayedFrom String?
The beginning of the delay range (format: -hh:mm:ss). E.g. in the expresssion "delayed from 30 to 60 minutes" stands for "from 30 minutes". Value can be negative (therefore, means early occurence). Must be preset if "DelayedTo" is not specified.
getter/setter pair
delayedTo String?
The end of the delay range (format: -hh:mm:ss). E.g. in the expresssion "delayed from 30 to 60 minutes" stands for "to 60 minutes". Value can be negative (therefore, means early occurence). Must be preset if "DelayedFrom" is not specified.
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
num_ int
Count of records subject to a specified delay range
getter/setter pair
percentage double?
Percentage of records subject to a specified delay range. Only available when this delay bracket is provided as a part of a statistical information of a bigger context and the "total" count of records is known.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) DelayBracketContract?
Returns a new DelayBracketContract instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<DelayBracketContract>
mapFromJson(dynamic json) Map<String, DelayBracketContract>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<DelayBracketContract>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.