EngineType class

Possible values:

  • 0 - Unknown
  • 1 - Jet
  • 2 - Turboprop
  • 3 - Piston

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) EngineType?
listFromJson(dynamic json, {bool growable = false}) List<EngineType>

Constants

jet → const EngineType
piston → const EngineType
turboprop → const EngineType
unknown → const EngineType
values → const List<EngineType>
List of all possible values in this EngineType.