FeedServiceStatus class

Descriptor of feed service status

Possible values:

  • 0 - Down: Service is provided, but is currently down
  • 1 - Degraded: Service is up and running, but performance is degraded: delays and disruptions are likely
  • 2 - OKPartial: Service is up and running normally, but updates vailable for not all or only few flights
  • 3 - OK: Service is up and running normally
  • -2 - Unknown: Status of service is unknown
  • -1 - Unavailable: Service is not provided

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) FeedServiceStatus?
listFromJson(dynamic json, {bool growable = false}) List<FeedServiceStatus>

Constants

degraded → const FeedServiceStatus
down → const FeedServiceStatus
OK → const FeedServiceStatus
oKPartial → const FeedServiceStatus
unavailable → const FeedServiceStatus
unknown → const FeedServiceStatus
values → const List<FeedServiceStatus>
List of all possible values in this FeedServiceStatus.