FlightAPIApi class

Constructors

FlightAPIApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAirportFlights(AirportCodesByEnum codeType, String code, DateTime fromLocal, DateTime toLocal, {FlightDirection? direction, bool? withLeg, bool? withCancelled, bool? withCodeshared, bool? withCargo, bool? withPrivate, bool? withLocation}) Future<AirportFidsContract?>
FIDS (airport departures and arrivals) - by local time range TIER 2
getAirportFlightsRelative(AirportCodesByEnum codeType, String code, {int? offsetMinutes, int? durationMinutes, FlightDirection? direction, bool? withLeg, bool? withCancelled, bool? withCodeshared, bool? withCargo, bool? withPrivate, bool? withLocation}) Future<AirportFidsContract?>
FIDS (airport departures and arrivals) - by relative time / by current time TIER 2
getAirportFlightsRelativeWithHttpInfo(AirportCodesByEnum codeType, String code, {int? offsetMinutes, int? durationMinutes, FlightDirection? direction, bool? withLeg, bool? withCancelled, bool? withCodeshared, bool? withCargo, bool? withPrivate, bool? withLocation}) Future<Response>
FIDS (airport departures and arrivals) - by relative time / by current time TIER 2
getAirportFlightsWithHttpInfo(AirportCodesByEnum codeType, String code, DateTime fromLocal, DateTime toLocal, {FlightDirection? direction, bool? withLeg, bool? withCancelled, bool? withCodeshared, bool? withCargo, bool? withPrivate, bool? withLocation}) Future<Response>
FIDS (airport departures and arrivals) - by local time range TIER 2
getFlight(FlightSearchByEnum searchBy, String searchParam, {DateTime? dateLocal, bool? withAircraftImage, bool? withLocation}) Future<List<FlightContract>?>
Flight status TIER 2
getFlightDates(FlightSearchByEnum searchBy, String searchParam, {DateTime? fromLocal, DateTime? toLocal}) Future<List<String>?>
Flight departure dates TIER 2
getFlightDatesWithHttpInfo(FlightSearchByEnum searchBy, String searchParam, {DateTime? fromLocal, DateTime? toLocal}) Future<Response>
Flight departure dates TIER 2
getFlightWithHttpInfo(FlightSearchByEnum searchBy, String searchParam, {DateTime? dateLocal, bool? withAircraftImage, bool? withLocation}) Future<Response>
Flight status TIER 2
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited