FlightAirlineContract class

Constructors

FlightAirlineContract({required String name, String? iata, String? icao})
Returns a new FlightAirlineContract instance.

Properties

hashCode int
The hash code for this object.
no setteroverride
iata String?
IATA code of the airline
getter/setter pair
icao String?
ICAO code of the airline
getter/setter pair
name String
Airline name
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) FlightAirlineContract?
Returns a new FlightAirlineContract instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<FlightAirlineContract>
mapFromJson(dynamic json) Map<String, FlightAirlineContract>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<FlightAirlineContract>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.