FlightAirportMovementContract class
Constructors
-
FlightAirportMovementContract({required ListingAirportContract airport, List<
FlightAirportMovementQualityEnum> quality = const [], FlightAirportMovementContractScheduledTime? scheduledTime, FlightAirportMovementContractRevisedTime? revisedTime, FlightAirportMovementContractRunwayTime? runwayTime, String? terminal, String? checkInDesk, String? gate, String? baggageBelt, String? runway}) - Returns a new FlightAirportMovementContract instance.
Properties
- airport ↔ ListingAirportContract
-
getter/setter pair
- baggageBelt ↔ String?
-
Baggage belt(s) for the flight (only for arriving flights)
getter/setter pair
- checkInDesk ↔ String?
-
Check-in desk(s) for the flight (only for departing flights)
getter/setter pair
- gate ↔ String?
-
Gate of (un)boarding for the flight
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
-
quality
↔ List<
FlightAirportMovementQualityEnum> -
Array of quality characteristics of the data. Check this to know which information you can expect within this contract (basic, live and/or approximate data).
getter/setter pair
- revisedTime ↔ FlightAirportMovementContractRevisedTime?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- runway ↔ String?
-
Name of a runway of landing (for arriving flights) or take-off (for departing flights), if known.
getter/setter pair
- runwayTime ↔ FlightAirportMovementContractRunwayTime?
-
getter/setter pair
- scheduledTime ↔ FlightAirportMovementContractScheduledTime?
-
getter/setter pair
- terminal ↔ String?
-
Terminal of the flight
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → FlightAirportMovementContract? -
Returns a new FlightAirportMovementContract instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< FlightAirportMovementContract> -
mapFromJson(
dynamic json) → Map< String, FlightAirportMovementContract> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< FlightAirportMovementContract> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.