quality property
Array of quality characteristics of the data. Check this to know which information you can expect within this contract (basic, live and/or approximate data).
Implementation
List<FlightAirportMovementQualityEnum> quality;
Array of quality characteristics of the data. Check this to know which information you can expect within this contract (basic, live and/or approximate data).
List<FlightAirportMovementQualityEnum> quality;