FlightAirportMovementQualityEnum class
Quality characteristics of the information provided within flight FlightAirportMovementContract
Possible values:
- 0 - Basic
- 1 - Live
- 2 - Approximate
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
dynamic value) → FlightAirportMovementQualityEnum? -
listFromJson(
dynamic json, {bool growable = false}) → List< FlightAirportMovementQualityEnum>
Constants
- approximate → const FlightAirportMovementQualityEnum
- basic → const FlightAirportMovementQualityEnum
- live → const FlightAirportMovementQualityEnum
-
values
→ const List<
FlightAirportMovementQualityEnum> - List of all possible values in this FlightAirportMovementQualityEnum.