FlightAlertAPIApi class

Constructors

FlightAlertAPIApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getWebhook(String subscriptionId) Future<SubscriptionContract?>
Get web-hook subscription FREE TIER
getWebhookList() Future<List<SubscriptionContract>?>
List web-hook subscriptions FREE TIER
getWebhookListWithHttpInfo() Future<Response>
List web-hook subscriptions FREE TIER
getWebhookWithHttpInfo(String subscriptionId) Future<Response>
Get web-hook subscription FREE TIER
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
refreshWebhook(String subscriptionId) Future<SubscriptionContract?>
Refresh web-hook subscription TIER 4
refreshWebhookWithHttpInfo(String subscriptionId) Future<Response>
Refresh web-hook subscription TIER 4
subscribeWebhook(SubscriptionSubjectType subjectType, String subjectId, {CreateWebHookSubscription? createWebHookSubscription}) Future<SubscriptionContract?>
Create web-hook subscription TIER 4
subscribeWebhookWithHttpInfo(SubscriptionSubjectType subjectType, String subjectId, {CreateWebHookSubscription? createWebHookSubscription}) Future<Response>
Create web-hook subscription TIER 4
toString() String
A string representation of this object.
inherited
unsubscribeWebhook(String subscriptionId) Future<void>
Remove web-hook subscription FREE TIER
unsubscribeWebhookWithHttpInfo(String subscriptionId) Future<Response>
Remove web-hook subscription FREE TIER

Operators

operator ==(Object other) bool
The equality operator.
inherited