getWebhook method
Get web-hook subscription FREE TIER
This endpoitns is a part of Flight alert PUSH API currently powered by webhooks. If you are running your own web service, you can subscribe to flights by number or airport code. After that, your HTTP endpoint will be called (notified) whenever the flight information gets updated. Gets information about an existing active web-hook subscription.
Parameters:
- String subscriptionId (required): Subscription ID
Implementation
Future<SubscriptionContract?> getWebhook(
String subscriptionId,
) async {
final response = await getWebhookWithHttpInfo(
subscriptionId,
);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty &&
response.statusCode != HttpStatus.noContent) {
return await apiClient.deserializeAsync(
await _decodeBodyBytes(response),
'SubscriptionContract',
) as SubscriptionContract;
}
return null;
}