getWebhookList method
List web-hook subscriptions FREE TIER
This endpoitns is a part of Flight alert PUSH API currently powered by webhooks. If you are running your own web service, you can subscribe to flights by number or airport code. After that, your HTTP endpoint will be called (notified) whenever the flight information gets updated. Get the list of existing active web-hook subscriptions
Implementation
Future<List<SubscriptionContract>?> getWebhookList() async {
final response = await getWebhookListWithHttpInfo();
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
// When a remote server returns no body with a status of 204, we shall not decode it.
// At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
// FormatException when trying to decode an empty string.
if (response.body.isNotEmpty &&
response.statusCode != HttpStatus.noContent) {
final responseBody = await _decodeBodyBytes(response);
return (await apiClient.deserializeAsync(
responseBody, 'List<SubscriptionContract>') as List)
.cast<SubscriptionContract>()
.toList(growable: false);
}
return null;
}