getWebhookListWithHttpInfo method

Future<Response> getWebhookListWithHttpInfo()

List web-hook subscriptions FREE TIER

This endpoitns is a part of Flight alert PUSH API currently powered by webhooks. If you are running your own web service, you can subscribe to flights by number or airport code. After that, your HTTP endpoint will be called (notified) whenever the flight information gets updated. Get the list of existing active web-hook subscriptions

Note: This method returns the HTTP Response.

Implementation

Future<Response> getWebhookListWithHttpInfo() async {
  // ignore: prefer_const_declarations
  final path = r'/subscriptions/webhook';

  // ignore: prefer_final_locals
  Object? postBody;

  final queryParams = <QueryParam>[];
  final headerParams = <String, String>{};
  final formParams = <String, String>{};

  const contentTypes = <String>[];

  return apiClient.invokeAPI(
    path,
    'GET',
    queryParams,
    postBody,
    headerParams,
    formParams,
    contentTypes.isEmpty ? null : contentTypes.first,
  );
}