getWebhookWithHttpInfo method
Get web-hook subscription FREE TIER
This endpoitns is a part of Flight alert PUSH API currently powered by webhooks. If you are running your own web service, you can subscribe to flights by number or airport code. After that, your HTTP endpoint will be called (notified) whenever the flight information gets updated. Gets information about an existing active web-hook subscription.
Note: This method returns the HTTP Response.
Parameters:
- String subscriptionId (required): Subscription ID
Implementation
Future<Response> getWebhookWithHttpInfo(
String subscriptionId,
) async {
// ignore: prefer_const_declarations
final path = r'/subscriptions/webhook/{subscriptionId}'
.replaceAll('{subscriptionId}', subscriptionId);
// ignore: prefer_final_locals
Object? postBody;
final queryParams = <QueryParam>[];
final headerParams = <String, String>{};
final formParams = <String, String>{};
const contentTypes = <String>[];
return apiClient.invokeAPI(
path,
'GET',
queryParams,
postBody,
headerParams,
formParams,
contentTypes.isEmpty ? null : contentTypes.first,
);
}