refreshWebhook method

Future<SubscriptionContract?> refreshWebhook(
  1. String subscriptionId
)

Refresh web-hook subscription TIER 4

This endpoitns is a part of Flight alert PUSH API currently powered by webhooks. If you are running your own web service, you can subscribe to flights by number or airport code. After that, your HTTP endpoint will be called (notified) whenever the flight information gets updated. Refreshes an existing web-hook subscription If the subscription had an expiration date-time set when created, this endpoint will extend it by the same period of time as the one it was originally created with. E.g., if subscription was originally created for 7 days, this endpoint will add extra 7 days to the expiration date-time. Note, that web-hook subscriptions cannot be extended beyond the sliding window of 60 days from the current date-time. If the subscription had no expiration date-time set, nothing occurs.

Parameters:

  • String subscriptionId (required): Subscription ID

Implementation

Future<SubscriptionContract?> refreshWebhook(
  String subscriptionId,
) async {
  final response = await refreshWebhookWithHttpInfo(
    subscriptionId,
  );
  if (response.statusCode >= HttpStatus.badRequest) {
    throw ApiException(response.statusCode, await _decodeBodyBytes(response));
  }
  // When a remote server returns no body with a status of 204, we shall not decode it.
  // At the time of writing this, `dart:convert` will throw an "Unexpected end of input"
  // FormatException when trying to decode an empty string.
  if (response.body.isNotEmpty &&
      response.statusCode != HttpStatus.noContent) {
    return await apiClient.deserializeAsync(
      await _decodeBodyBytes(response),
      'SubscriptionContract',
    ) as SubscriptionContract;
  }
  return null;
}