refreshWebhookWithHttpInfo method
Refresh web-hook subscription TIER 4
This endpoitns is a part of Flight alert PUSH API currently powered by webhooks. If you are running your own web service, you can subscribe to flights by number or airport code. After that, your HTTP endpoint will be called (notified) whenever the flight information gets updated. Refreshes an existing web-hook subscription If the subscription had an expiration date-time set when created, this endpoint will extend it by the same period of time as the one it was originally created with. E.g., if subscription was originally created for 7 days, this endpoint will add extra 7 days to the expiration date-time. Note, that web-hook subscriptions cannot be extended beyond the sliding window of 60 days from the current date-time. If the subscription had no expiration date-time set, nothing occurs.
Note: This method returns the HTTP Response.
Parameters:
- String subscriptionId (required): Subscription ID
Implementation
Future<Response> refreshWebhookWithHttpInfo(
String subscriptionId,
) async {
// ignore: prefer_const_declarations
final path = r'/subscriptions/webhook/{subscriptionId}/refresh'
.replaceAll('{subscriptionId}', subscriptionId);
// ignore: prefer_final_locals
Object? postBody;
final queryParams = <QueryParam>[];
final headerParams = <String, String>{};
final formParams = <String, String>{};
const contentTypes = <String>[];
return apiClient.invokeAPI(
path,
'PATCH',
queryParams,
postBody,
headerParams,
formParams,
contentTypes.isEmpty ? null : contentTypes.first,
);
}