unsubscribeWebhookWithHttpInfo method

Future<Response> unsubscribeWebhookWithHttpInfo(
  1. String subscriptionId
)

Remove web-hook subscription FREE TIER

This endpoitns is a part of Flight alert PUSH API currently powered by webhooks. If you are running your own web service, you can subscribe to flights by number or airport code. After that, your HTTP endpoint will be called (notified) whenever the flight information gets updated. Removes the subscription

Note: This method returns the HTTP Response.

Parameters:

  • String subscriptionId (required): Subscription ID

Implementation

Future<Response> unsubscribeWebhookWithHttpInfo(
  String subscriptionId,
) async {
  // ignore: prefer_const_declarations
  final path = r'/subscriptions/webhook/{subscriptionId}'
      .replaceAll('{subscriptionId}', subscriptionId);

  // ignore: prefer_final_locals
  Object? postBody;

  final queryParams = <QueryParam>[];
  final headerParams = <String, String>{};
  final formParams = <String, String>{};

  const contentTypes = <String>[];

  return apiClient.invokeAPI(
    path,
    'DELETE',
    queryParams,
    postBody,
    headerParams,
    formParams,
    contentTypes.isEmpty ? null : contentTypes.first,
  );
}