numQualifiedTotal property

int numQualifiedTotal
getter/setter pair

Total number of flights in the batch, which were used to to calculate the delay information (including cancelled). Should equal to or less than NumTotal. The closer the value of this property to the value of NumTotal, the higher the reliability of delay information

Implementation

int numQualifiedTotal;