FlightContract class

Constructors

FlightContract({required FlightAirportMovementContract departure, required FlightAirportMovementContract arrival, required DateTime lastUpdatedUtc, required String number, required FlightStatus status, required CodeshareStatus codeshareStatus, required bool isCargo, FlightContractGreatCircleDistance? greatCircleDistance, String? callSign, AirportFlightContractAircraft? aircraft, AirportFlightContractAirline? airline, AirportFlightContractLocation? location})
Returns a new FlightContract instance.

Properties

aircraft AirportFlightContractAircraft?
getter/setter pair
airline AirportFlightContractAirline?
getter/setter pair
arrival FlightAirportMovementContract
getter/setter pair
callSign String?
ATC call-sign of the flight
getter/setter pair
codeshareStatus CodeshareStatus
getter/setter pair
departure FlightAirportMovementContract
getter/setter pair
greatCircleDistance FlightContractGreatCircleDistance?
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
isCargo bool
Is cargo flight
getter/setter pair
lastUpdatedUtc DateTime
Time (UTC) of the latest update of flight information (excluding Location)
getter/setter pair
location AirportFlightContractLocation?
getter/setter pair
number String
Flight Number
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status FlightStatus
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) FlightContract?
Returns a new FlightContract instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<FlightContract>
mapFromJson(dynamic json) Map<String, FlightContract>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<FlightContract>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.