FlightDataGeneralAvailabilityContract class

Constructors

FlightDataGeneralAvailabilityContract({required DateTime minAvailableLocalDate, required DateTime maxAvailableLocalDate})
Returns a new FlightDataGeneralAvailabilityContract instance.

Properties

hashCode int
The hash code for this object.
no setteroverride
maxAvailableLocalDate DateTime
Date of the most recent flight stored (based on scheduled local times)
getter/setter pair
minAvailableLocalDate DateTime
Date of the oldest flight stored (based on scheduled local times)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) FlightDataGeneralAvailabilityContract?
Returns a new FlightDataGeneralAvailabilityContract instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<FlightDataGeneralAvailabilityContract>
mapFromJson(dynamic json) Map<String, FlightDataGeneralAvailabilityContract>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<FlightDataGeneralAvailabilityContract>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.