FlightDirection class

Direction of flight

Possible values:

  • 1 - Arrival
  • 2 - Departure
  • 3 - Both

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) FlightDirection?
listFromJson(dynamic json, {bool growable = false}) List<FlightDirection>

Constants

arrival → const FlightDirection
both → const FlightDirection
departure → const FlightDirection
values → const List<FlightDirection>
List of all possible values in this FlightDirection.