FlightSearchByEnum class

Criteria to search flight by

Possible values:

  • 0 - Number: Search by flight number
  • 1 - Reg: Search by aircraft registration
  • 2 - CallSign: Search by ATC call-sign
  • 3 - Icao24: Search by 24-bit ICAO Mode-S Transponder code

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) FlightSearchByEnum?
listFromJson(dynamic json, {bool growable = false}) List<FlightSearchByEnum>

Constants

callSign → const FlightSearchByEnum
icao24 → const FlightSearchByEnum
number → const FlightSearchByEnum
reg → const FlightSearchByEnum
values → const List<FlightSearchByEnum>
List of all possible values in this FlightSearchByEnum.