FlightStatus class
Flight progress status
Possible values:
- 0 - Unknown: Information is not provided
- 1 - Expected: Expected
- 2 - EnRoute: En route
- 3 - CheckIn: Check-in is open
- 4 - Boarding: Boarding in progress / Last call
- 5 - GateClosed: Gate closed
- 6 - Departed: Departed
- 7 - Delayed: Delayed
- 8 - Approaching: On approach to destination
- 9 - Arrived: Arrived
- 10 - Canceled: Cancelled
- 11 - Diverted: Diverted to another destination
- 12 - CanceledUncertain: Probably cancelled, as no expected updates came for the flight
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
dynamic value) → FlightStatus? -
listFromJson(
dynamic json, {bool growable = false}) → List< FlightStatus>
Constants
- approaching → const FlightStatus
- arrived → const FlightStatus
- boarding → const FlightStatus
- canceled → const FlightStatus
- canceledUncertain → const FlightStatus
- checkIn → const FlightStatus
- delayed → const FlightStatus
- departed → const FlightStatus
- diverted → const FlightStatus
- enRoute → const FlightStatus
- expected → const FlightStatus
- gateClosed → const FlightStatus
- unknown → const FlightStatus
-
values
→ const List<
FlightStatus> - List of all possible values in this FlightStatus.