GeoCoordinatesContract class

Constructors

GeoCoordinatesContract({required double lat, required double lon})
Returns a new GeoCoordinatesContract instance.

Properties

hashCode int
The hash code for this object.
no setteroverride
lat double
Latitude, in degrees
getter/setter pair
lon double
Longitude, in degrees
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) GeoCoordinatesContract?
Returns a new GeoCoordinatesContract instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<GeoCoordinatesContract>
mapFromJson(dynamic json) Map<String, GeoCoordinatesContract>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<GeoCoordinatesContract>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.