HealthcheckAPIApi class

Constructors

HealthcheckAPIApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAirportFeedStatus(String icao) Future<AirportFeedServiceStatusContract?>
Data feed services status by ICAO code FREE TIER
getAirportFeedStatusWithHttpInfo(String icao) Future<Response>
Data feed services status by ICAO code FREE TIER
getFeedAirports(FeedServiceEnum service) Future<StringCollectionContract?>
Airports supporting data feed service FREE TIER
getFeedAirportsWithHttpInfo(FeedServiceEnum service) Future<Response>
Airports supporting data feed service FREE TIER
getFeedServiceStatus(FeedServiceEnum service, {bool? withHttpCode}) Future<FeedServiceStatusContract?>
General status of data feed services FREE TIER
getFeedServiceStatusWithHttpInfo(FeedServiceEnum service, {bool? withHttpCode}) Future<Response>
General status of data feed services FREE TIER
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited