getFeedServiceStatusWithHttpInfo method
Future<Response>
getFeedServiceStatusWithHttpInfo(
- FeedServiceEnum service, {
- bool? withHttpCode,
General status of data feed services FREE TIER
Which is the general health of the data feed service? Returns: Status of the service in general, regardless of the airports
Note: This method returns the HTTP Response.
Parameters:
-
FeedServiceEnum service (required): Data feed service name
-
bool withHttpCode: If true, reflect status of the service in the HTTP code of the response (if the service is down, HTTP code will be 503).
Implementation
Future<Response> getFeedServiceStatusWithHttpInfo(
FeedServiceEnum service, {
bool? withHttpCode,
}) async {
// ignore: prefer_const_declarations
final path = r'/health/services/feeds/{service}'
.replaceAll('{service}', service.toString());
// ignore: prefer_final_locals
Object? postBody;
final queryParams = <QueryParam>[];
final headerParams = <String, String>{};
final formParams = <String, String>{};
if (withHttpCode != null) {
queryParams.addAll(_queryParams('', 'withHttpCode', withHttpCode));
}
const contentTypes = <String>[];
return apiClient.invokeAPI(
path,
'GET',
queryParams,
postBody,
headerParams,
formParams,
contentTypes.isEmpty ? null : contentTypes.first,
);
}