LicenseType class

Possible values:

  • 0 - AllRightsReserved: All Rights Reserved.
  • 1 - AttributionNoncommercialShareAlikeCC: Creative Commons: Attribution Non-Commercial, Share-alike License.
  • 2 - AttributionNoncommercialCC: Creative Commons: Attribution Non-Commercial License.
  • 3 - AttributionNoncommercialNoDerivativesCC: Creative Commons: Attribution Non-Commercial, No Derivatives License.
  • 4 - AttributionCC: Creative Commons: Attribution License.
  • 5 - AttributionShareAlikeCC: Creative Commons: Attribution Share-alike License.
  • 6 - AttributionNoDerivativesCC: Creative Commons: Attribution No Derivatives License.
  • 7 - NoKnownCopyrightRestrictions: No Known Copyright Resitrctions (Flickr Commons).
  • 8 - UnitedStatesGovernmentWork: United States Government Work
  • 9 - PublicDomainDedicationCC0: Public Domain Dedication, CC0
  • 10 - PublicDomainMark: Public Domain Mark

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) LicenseType?
listFromJson(dynamic json, {bool growable = false}) List<LicenseType>