MiscellaneousAPIApi class

Constructors

MiscellaneousAPIApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAirportDistanceTime(AirportCodesByEnum codeType, String codeFrom, String codeTo, {String? aircraftName, ModelFlightTimeEnum? flightTimeModel}) Future<AirportDistanceTimeContract?>
🤖 Distance and flight time between airports TIER 2
getAirportDistanceTimeWithHttpInfo(AirportCodesByEnum codeType, String codeFrom, String codeTo, {String? aircraftName, ModelFlightTimeEnum? flightTimeModel}) Future<Response>
🤖 Distance and flight time between airports TIER 2
getAirportLocalTime(AirportCodesByEnum codeType, String code) Future<AirportLocalTimeContract?>
Current local time at the airport TIER 1
getAirportLocalTimeWithHttpInfo(AirportCodesByEnum codeType, String code) Future<Response>
Current local time at the airport TIER 1
getAirportSolarTime(AirportCodesByEnum codeType, String code, {DateTime? dateLocal}) Future<SolarStateContract?>
Solar and day time at the airport TIER 1
getAirportSolarTimeWithHttpInfo(AirportCodesByEnum codeType, String code, {DateTime? dateLocal}) Future<Response>
Solar and day time at the airport TIER 1
getAirportWeather(AirportCodesByEnum codeType, String code, {DateTime? fromLocal, DateTime? toLocal}) Future<List<WeatherStateContract>?>
Weather / forecast at the airport TIER 2
getAirportWeatherWithHttpInfo(AirportCodesByEnum codeType, String code, {DateTime? fromLocal, DateTime? toLocal}) Future<Response>
Weather / forecast at the airport TIER 2
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited