getAirportLocalTimeWithHttpInfo method

Future<Response> getAirportLocalTimeWithHttpInfo(
  1. AirportCodesByEnum codeType,
  2. String code
)

Current local time at the airport TIER 1

What is the current local time at the airport? At the moment airports having both ICAO and IATA code are present in database only. Returns: Local time at the airport, if airport is found.

Note: This method returns the HTTP Response.

Parameters:

  • AirportCodesByEnum codeType (required): Type of code to search airport by (iata or icao)

  • String code (required): If codeType is: * icao, then this field must be a 4-character ICAO-code of the airport (e.g.: EHAM, KLAX, UUEE, etc.); * iata, then this field must be a 3-character IATA-code of the airport (e.g.: AMS, SFO, LAX, etc.). Full, stripped and any case formats are acceptable.

Implementation

Future<Response> getAirportLocalTimeWithHttpInfo(
  AirportCodesByEnum codeType,
  String code,
) async {
  // ignore: prefer_const_declarations
  final path = r'/airports/{codeType}/{code}/time/local'
      .replaceAll('{codeType}', codeType.toString())
      .replaceAll('{code}', code);

  // ignore: prefer_final_locals
  Object? postBody;

  final queryParams = <QueryParam>[];
  final headerParams = <String, String>{};
  final formParams = <String, String>{};

  const contentTypes = <String>[];

  return apiClient.invokeAPI(
    path,
    'GET',
    queryParams,
    postBody,
    headerParams,
    formParams,
    contentTypes.isEmpty ? null : contentTypes.first,
  );
}