PercentileBracketContract class

Constructors

PercentileBracketContract({required int percentile, required String delay})
Returns a new PercentileBracketContract instance.

Properties

delay String
Delay of the flight for the specific percentile (format: -hh:mm:ss).
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
percentile int
Percentile of the distribution
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) PercentileBracketContract?
Returns a new PercentileBracketContract instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<PercentileBracketContract>
mapFromJson(dynamic json) Map<String, PercentileBracketContract>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<PercentileBracketContract>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.