Pressure class

Constructors

Pressure({required double hPa, required double inHg, required double mmHg})
Returns a new Pressure instance.

Properties

hashCode int
The hash code for this object.
no setteroverride
hPa double
Pressure in hectopascals
getter/setter pair
inHg double
Pressure in inches mercury
getter/setter pair
mmHg double
Pressure in millimeters mercury
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) Pressure?
Returns a new Pressure instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<Pressure>
mapFromJson(dynamic json) Map<String, Pressure>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<Pressure>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.