ResourceContract class
Constructors
-
ResourceContract({required String url, required LicenseType license, String? webUrl, String? author, String? title, String? description, List<
String> ? htmlAttributions = const []}) - Returns a new ResourceContract instance.
Properties
-
Author name of the resource
getter/setter pair
- description ↔ String?
-
Description of the resource
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
-
htmlAttributions
↔ List<
String> ? -
Attributions maintaining copyright, ownership and other legal information adjusted for displaying as HTML. Each element represent one line.
getter/setter pair
- license ↔ LicenseType
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title ↔ String?
-
Title of the resource
getter/setter pair
- url ↔ String
-
URL of the resource
getter/setter pair
- webUrl ↔ String?
-
URL of web-page containing the resource
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → ResourceContract? -
Returns a new ResourceContract instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< ResourceContract> -
mapFromJson(
dynamic json) → Map< String, ResourceContract> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< ResourceContract> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.