Speed class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- kmPerHour ↔ double
-
Speed in km per hour
getter/setter pair
- kt ↔ double
-
Speed in knots
getter/setter pair
- meterPerSecond ↔ double
-
Speed in meters per second
getter/setter pair
- miPerHour ↔ double
-
Speed in miles per hour
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → Speed? -
Returns a new Speed instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< Speed> -
mapFromJson(
dynamic json) → Map< String, Speed> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< Speed> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.