StatisticalAPIApi class

Constructors

StatisticalAPIApi([ApiClient? apiClient])

Properties

apiClient ApiClient
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAirportDelay(AirportCodesByEnum codeType, String code, {DateTime? dateLocal}) Future<AirportDelayContract?>
Airport delays (current or historical moment) TIER 3
getAirportDelays(AirportCodesByEnum codeType, String code, DateTime dateFromLocal, DateTime dateToLocal) Future<List<AirportDelayContract>?>
Airport delays (historical period) TIER 3
getAirportDelaysWithHttpInfo(AirportCodesByEnum codeType, String code, DateTime dateFromLocal, DateTime dateToLocal) Future<Response>
Airport delays (historical period) TIER 3
getAirportDelayWithHttpInfo(AirportCodesByEnum codeType, String code, {DateTime? dateLocal}) Future<Response>
Airport delays (current or historical moment) TIER 3
getAllAirportDelays({DateTime? dateUtc}) Future<AirportDelayContract?>
Global delays (current or historical moment) TIER 3
getAllAirportDelaysWithHttpInfo({DateTime? dateUtc}) Future<Response>
Global delays (current or historical moment) TIER 3
getFlightDelays(String number) Future<FlightLegDelayContract?>
Flight delay statistics by flight number TIER 3
getFlightDelaysWithHttpInfo(String number) Future<Response>
Flight delay statistics by flight number TIER 3
getRouteDailyStatistics(AirportCodesByEnum codeType, String code, {DateTime? dateLocal}) Future<DailyRouteStatContract?>
Airport routes and daily flight destinations TIER 3
getRouteDailyStatisticsWithHttpInfo(AirportCodesByEnum codeType, String code, {DateTime? dateLocal}) Future<Response>
Airport routes and daily flight destinations TIER 3
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited