getFlightDelaysWithHttpInfo method

Future<Response> getFlightDelaysWithHttpInfo(
  1. String number
)

Flight delay statistics by flight number TIER 3

By how much the flight is delayed in average? Information is only available for flights which were tracked with live updates at least at origin or at destination within the last 90 days. Returns: delay statistics for the flight with specified number.

Note: This method returns the HTTP Response.

Parameters:

  • String number (required): Flight number (with or without spaces, IATA or ICAO, any case formats are acceptable, e.g. KL1395, Klm 1395)

Implementation

Future<Response> getFlightDelaysWithHttpInfo(
  String number,
) async {
  // ignore: prefer_const_declarations
  final path = r'/flights/{number}/delays'.replaceAll('{number}', number);

  // ignore: prefer_final_locals
  Object? postBody;

  final queryParams = <QueryParam>[];
  final headerParams = <String, String>{};
  final formParams = <String, String>{};

  const contentTypes = <String>[];

  return apiClient.invokeAPI(
    path,
    'GET',
    queryParams,
    postBody,
    headerParams,
    formParams,
    contentTypes.isEmpty ? null : contentTypes.first,
  );
}