StringCollectionContract class

Constructors

StringCollectionContract({required int count, List<String> items = const []})
Returns a new StringCollectionContract instance.

Properties

count int
The number of items in the collection
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
items List<String>
The collection of items
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) StringCollectionContract?
Returns a new StringCollectionContract instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<StringCollectionContract>
mapFromJson(dynamic json) Map<String, StringCollectionContract>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<StringCollectionContract>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.