searchBy property
Search parameter used to find the result. Please note, it may be different from the actual input provided!
Implementation
String searchBy;
Search parameter used to find the result. Please note, it may be different from the actual input provided!
String searchBy;