SubscriberContract class

Constructors

SubscriberContract({required String type, required String id})
Returns a new SubscriberContract instance.

Properties

hashCode int
The hash code for this object.
no setteroverride
id String
ID
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
Type of subscriber. Completemented by SubscriberId.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) SubscriberContract?
Returns a new SubscriberContract instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<SubscriberContract>
mapFromJson(dynamic json) Map<String, SubscriberContract>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<SubscriberContract>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.