SubscriptionSubjectContract class

Constructors

SubscriptionSubjectContract({required SubscriptionSubjectType type, String? id})
Returns a new SubscriptionSubjectContract instance.

Properties

hashCode int
The hash code for this object.
no setteroverride
id String?
Subject ID of a subscription. Complements SubjectType. E.g. SubjectType = "FlightNumber" and SubjectId = "DL 47" means that this subscription is for all updates of flight with number DL47.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type SubscriptionSubjectType
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) SubscriptionSubjectContract?
Returns a new SubscriptionSubjectContract instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<SubscriptionSubjectContract>
mapFromJson(dynamic json) Map<String, SubscriptionSubjectContract>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<SubscriptionSubjectContract>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.