id property
Subject ID of a subscription. Complements SubjectType. E.g. SubjectType = "FlightNumber" and SubjectId = "DL 47" means that this subscription is for all updates of flight with number DL47.
Implementation
String? id;
Subject ID of a subscription. Complements SubjectType. E.g. SubjectType = "FlightNumber" and SubjectId = "DL 47" means that this subscription is for all updates of flight with number DL47.
String? id;