SurfaceType class

Possible values:

  • 0 - Unknown
  • 1 - Asphalt
  • 2 - Concrete
  • 3 - Grass
  • 4 - Dirt
  • 5 - Gravel
  • 6 - DryLakebed
  • 7 - Water
  • 8 - Snow

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The underlying value of this enum member.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(dynamic value) SurfaceType?
listFromJson(dynamic json, {bool growable = false}) List<SurfaceType>

Constants

asphalt → const SurfaceType
concrete → const SurfaceType
dirt → const SurfaceType
dryLakebed → const SurfaceType
grass → const SurfaceType
gravel → const SurfaceType
snow → const SurfaceType
unknown → const SurfaceType
values → const List<SurfaceType>
List of all possible values in this SurfaceType.
water → const SurfaceType