WeatherStateContract class

Constructors

WeatherStateContract({required GeoCoordinatesContract location, required DateTimeContract validFrom, required DateTimeContract validTo, WeatherStateContractAirTemperature? airTemperature, WeatherStateContractDewPoint? dewPoint, WeatherStateContractPressure? pressure, WeatherStateContractWind? wind, WeatherStateContractVisibility? visibility, String? report, WeatherStateContractCloudBase? cloudBase, CloudCover? cloudCover, List<PhenomenaGroup>? phenomenaGroups = const []})
Returns a new WeatherStateContract instance.

Properties

airTemperature WeatherStateContractAirTemperature?
getter/setter pair
cloudBase WeatherStateContractCloudBase?
getter/setter pair
cloudCover CloudCover?
getter/setter pair
dewPoint WeatherStateContractDewPoint?
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
location GeoCoordinatesContract
getter/setter pair
phenomenaGroups List<PhenomenaGroup>?
Weather phenomena groups
getter/setter pair
pressure WeatherStateContractPressure?
getter/setter pair
report String?
Aviation weather report (typically a METAR or TAF string, as applicable)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
validFrom DateTimeContract
getter/setter pair
validTo DateTimeContract
getter/setter pair
visibility WeatherStateContractVisibility?
getter/setter pair
wind WeatherStateContractWind?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) WeatherStateContract?
Returns a new WeatherStateContract instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<WeatherStateContract>
mapFromJson(dynamic json) Map<String, WeatherStateContract>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<WeatherStateContract>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.