WeatherStateContractCloudBase class

Constructors

WeatherStateContractCloudBase({required double meter, required double km, required double mile, required double nm, required double feet})
Returns a new WeatherStateContractCloudBase instance.

Properties

feet double
Distance in feet
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
km double
Distance in kilometers
getter/setter pair
meter double
Distance in meters
getter/setter pair
mile double
Distance in statute miles
getter/setter pair
nm double
Distance in nautical miles
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) WeatherStateContractCloudBase?
Returns a new WeatherStateContractCloudBase instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<WeatherStateContractCloudBase>
mapFromJson(dynamic json) Map<String, WeatherStateContractCloudBase>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<WeatherStateContractCloudBase>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.