WeatherStateContractDewPoint class

Constructors

WeatherStateContractDewPoint({required double c, required double f, required double k})
Returns a new WeatherStateContractDewPoint instance.

Properties

c double
Temperature in degrees Celcius
getter/setter pair
f double
Distance in degrees Fahrenheit
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
k double
Temperature in degrees Kelvin
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) WeatherStateContractDewPoint?
Returns a new WeatherStateContractDewPoint instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<WeatherStateContractDewPoint>
mapFromJson(dynamic json) Map<String, WeatherStateContractDewPoint>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<WeatherStateContractDewPoint>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.