WeatherStateContractWind class

Constructors

WeatherStateContractWind({required Speed speed, required Azimuth direction, WindContractGusts? gusts})
Returns a new WeatherStateContractWind instance.

Properties

direction Azimuth
getter/setter pair
gusts WindContractGusts?
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed Speed
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) WeatherStateContractWind?
Returns a new WeatherStateContractWind instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<WeatherStateContractWind>
mapFromJson(dynamic json) Map<String, WeatherStateContractWind>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<WeatherStateContractWind>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.