AircraftContract class

Constructors

AircraftContract({required int id, required String reg, required bool active, required bool isFreighter, required bool verified, required int numRegistrations, String? serial, String? hexIcao, String? airlineName, String? iataType, String? iataCodeShort, String? icaoCode, String? model, String? modelCode, int? numSeats, DateTime? rolloutDate, DateTime? firstFlightDate, DateTime? deliveryDate, DateTime? registrationDate, String? typeName, int? numEngines, EngineType? engineType, String? productionLine, double? ageYears, AircraftContractImage? image, List<AircraftRegistrationContract>? registrations = const []})
Returns a new AircraftContract instance.

Properties

active bool
Indicator if aircraft is operational under this registration
getter/setter pair
ageYears double?
Age of the aircraft in year
getter/setter pair
airlineName String?
Name of the airline operating the aircraft
getter/setter pair
deliveryDate DateTime?
Date of delivery to the owner
getter/setter pair
engineType EngineType?
getter/setter pair
firstFlightDate DateTime?
First flight date
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
hexIcao String?
ICAO 24 bit Mode-S hexadecimal transponder address
getter/setter pair
iataCodeShort String?
Short variant of IATA-code of the aircraft
getter/setter pair
iataType String?
IATA-type of the aircraft
getter/setter pair
icaoCode String?
ICAO-code of the aircraft
getter/setter pair
id int
Unique ID of the aircraft record in our database
getter/setter pair
image AircraftContractImage?
getter/setter pair
isFreighter bool
Marker if aircraft is cargo or not
getter/setter pair
model String?
Model of the aircraft
getter/setter pair
modelCode String?
Model code of the aircraft
getter/setter pair
numEngines int?
Number of engines
getter/setter pair
numRegistrations int
An aircraft may have a history of past registrations with other airlines or operators. This field represents a total number of registration records known in our database.
getter/setter pair
numSeats int?
Number of passenger seats
getter/setter pair
productionLine String?
Production line
getter/setter pair
reg String
Tail-number of the aircraft
getter/setter pair
registrationDate DateTime?
Date of assigning current registration
getter/setter pair
registrations List<AircraftRegistrationContract>?
A history of all registrations with other airlines or operators (if provided by the endpoint).
getter/setter pair
rolloutDate DateTime?
Date of roll-out (UTC)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serial String?
Serial number
getter/setter pair
typeName String?
Type name
getter/setter pair
verified bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) AircraftContract?
Returns a new AircraftContract instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<AircraftContract>
mapFromJson(dynamic json) Map<String, AircraftContract>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<AircraftContract>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.