recognized property
Object containing aircrafts recognized. Property key is aircraft registration recognized on the media resource. Property value is an object with aircraft data found in database for corresponding registration. If nothing is found, the value will be null.
Implementation
Map<String, AircraftContract> recognized;