AirportFlightContract class
Constructors
- AirportFlightContract({required String number, required FlightStatus status, required bool isCargo, AirportFlightContractMovement? movement, AirportFlightContractDeparture? departure, AirportFlightContractArrival? arrival, String? callSign, AirportFlightContractAircraft? aircraft, AirportFlightContractAirline? airline, AirportFlightContractLocation? location})
- Returns a new AirportFlightContract instance.
Properties
- aircraft ↔ AirportFlightContractAircraft?
-
getter/setter pair
- airline ↔ AirportFlightContractAirline?
-
getter/setter pair
- arrival ↔ AirportFlightContractArrival?
-
getter/setter pair
- callSign ↔ String?
-
ATC call-sign of the flight
getter/setter pair
-
getter/setter pair
- departure ↔ AirportFlightContractDeparture?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- isCargo ↔ bool
-
Is cargo flight
getter/setter pair
- location ↔ AirportFlightContractLocation?
-
getter/setter pair
- movement ↔ AirportFlightContractMovement?
-
getter/setter pair
- number ↔ String
-
Flight Number
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status ↔ FlightStatus
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → AirportFlightContract? -
Returns a new AirportFlightContract instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< AirportFlightContract> -
mapFromJson(
dynamic json) → Map< String, AirportFlightContract> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< AirportFlightContract> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.