CreateWebHookSubscription class

Constructors

CreateWebHookSubscription({required String url})
Returns a new CreateWebHookSubscription instance.

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
Destination HTTP-endpoint where notifications will be sent to. Requirements: * must be a valid public HTTP(S) URL not requiring additional authorization; * must use standard or alternative HTTP or HTTPS ports (80, 443, 8008, 8080) or any dynamic port greater or equal to 49152; * must be able to accept HTTP POST request with JSON-formatted body (application/json); * must respond with one of successful HTTP status codes (2XX) within 10 seconds; * the endpoint owner must be aware of and consent to receiving notifications at it.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) CreateWebHookSubscription?
Returns a new CreateWebHookSubscription instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<CreateWebHookSubscription>
mapFromJson(dynamic json) Map<String, CreateWebHookSubscription>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<CreateWebHookSubscription>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.