DelayBracketContract class
Properties
-
delayedFrom
↔ String?
-
The beginning of the delay range (format:
-hh:mm:ss). E.g. in the expresssion "delayed from 30 to 60 minutes" stands for "from 30 minutes". Value can be negative (therefore, means early occurence). Must be preset if "DelayedTo" is not specified.
getter/setter pair
-
delayedTo
↔ String?
-
The end of the delay range (format:
-hh:mm:ss). E.g. in the expresssion "delayed from 30 to 60 minutes" stands for "to 60 minutes". Value can be negative (therefore, means early occurence). Must be preset if "DelayedFrom" is not specified.
getter/setter pair
-
hashCode
→ int
-
The hash code for this object.
no setteroverride
-
num_
↔ int
-
Count of records subject to a specified delay range
getter/setter pair
-
percentage
↔ double?
-
Percentage of records subject to a specified delay range. Only available when this delay bracket is provided as a part of a statistical information of a bigger context and the "total" count of records is known.
getter/setter pair
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited