FeedServiceEnum class
Airport feed service defininitions
Possible values:
- 0 - FlightSchedules: Flight schedules data feed for this airport (static schedules data without actual updates)
- 1 - FlightLiveUpdates: Actual flight status and time updates for this airport
- 2 - AdsbUpdates: Flight updates derived from ADS-B data for this airport: runway, actual/estimated time on the runway, call-sign, ModeS 24-bit ICAO code, aircraft registration
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
dynamic value) → FeedServiceEnum? -
listFromJson(
dynamic json, {bool growable = false}) → List< FeedServiceEnum>
Constants
- adsbUpdates → const FeedServiceEnum
- flightLiveUpdates → const FeedServiceEnum
- flightSchedules → const FeedServiceEnum
-
values
→ const List<
FeedServiceEnum> - List of all possible values in this FeedServiceEnum.