FlightAircraftContract class
Constructors
- FlightAircraftContract({String? reg, String? modeS, String? model, FlightAircraftContractImage? image})
- Returns a new FlightAircraftContract instance.
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- image ↔ FlightAircraftContractImage?
-
getter/setter pair
- model ↔ String?
-
Aircraft name and model
getter/setter pair
- modeS ↔ String?
-
ICAO 24 bit Mode-S hexadecimal transponder address
getter/setter pair
- reg ↔ String?
-
Tail-number of the aircraft
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → FlightAircraftContract? -
Returns a new FlightAircraftContract instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< FlightAircraftContract> -
mapFromJson(
dynamic json) → Map< String, FlightAircraftContract> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< FlightAircraftContract> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.