unsubscribeWebhook method
Remove web-hook subscription FREE TIER
This endpoitns is a part of Flight alert PUSH API currently powered by webhooks. If you are running your own web service, you can subscribe to flights by number or airport code. After that, your HTTP endpoint will be called (notified) whenever the flight information gets updated. Removes the subscription
Parameters:
- String subscriptionId (required): Subscription ID
Implementation
Future<void> unsubscribeWebhook(
String subscriptionId,
) async {
final response = await unsubscribeWebhookWithHttpInfo(
subscriptionId,
);
if (response.statusCode >= HttpStatus.badRequest) {
throw ApiException(response.statusCode, await _decodeBodyBytes(response));
}
}