FlightBatchDelayContract class

Constructors

FlightBatchDelayContract({required int numTotal, required int numQualifiedTotal, required int numCancelled, String? medianDelay, double? delayIndex})
Returns a new FlightBatchDelayContract instance.

Properties

delayIndex double?
Normalized value on scale from 0.0 to 5.0 which corresponds with current amount of delays and cancellations in a given batch of flights (the less - the better).
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
medianDelay String?
Median delay of flights in the batch (format: -hh:mm:ss). Value can be negative (therefore, means early occurence).
getter/setter pair
numCancelled int
Total amount of flights in the batch
getter/setter pair
numQualifiedTotal int
Total number of flights in the batch, which were used to to calculate the delay information (including cancelled). Should equal to or less than NumTotal. The closer the value of this property to the value of NumTotal, the higher the reliability of delay information
getter/setter pair
numTotal int
Total number of flights in the the batch (including cancelled)
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

fromJson(dynamic value) FlightBatchDelayContract?
Returns a new FlightBatchDelayContract instance and imports its values from value if it's a Map, null otherwise.
listFromJson(dynamic json, {bool growable = false}) List<FlightBatchDelayContract>
mapFromJson(dynamic json) Map<String, FlightBatchDelayContract>
mapListFromJson(dynamic json, {bool growable = false}) Map<String, List<FlightBatchDelayContract>>

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.