FlightLegDelayContract class
Constructors
-
FlightLegDelayContract({required String number, List<
FlightDelayContract> ? origins = const [], List<FlightDelayContract> ? destinations = const []}) - Returns a new FlightLegDelayContract instance.
Properties
-
destinations
↔ List<
FlightDelayContract> ? -
Delay statistics of flight on arrival at destinations
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- number ↔ String
-
Flight number
getter/setter pair
-
origins
↔ List<
FlightDelayContract> ? -
Delay statistics of flight on departure at origins
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → FlightLegDelayContract? -
Returns a new FlightLegDelayContract instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< FlightLegDelayContract> -
mapFromJson(
dynamic json) → Map< String, FlightLegDelayContract> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< FlightLegDelayContract> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.