FlightLocationContract class
Constructors
- FlightLocationContract({required Distance pressureAltitude, required Distance altitude, required Pressure pressure, required Speed groundSpeed, required Azimuth trueTrack, required DateTime reportedAtUtc, required double lat, required double lon})
- Returns a new FlightLocationContract instance.
Properties
- altitude ↔ Distance
-
getter/setter pair
- groundSpeed ↔ Speed
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- lat ↔ double
-
Latitude, in degrees
getter/setter pair
- lon ↔ double
-
Longitude, in degrees
getter/setter pair
- pressure ↔ Pressure
-
getter/setter pair
- pressureAltitude ↔ Distance
-
getter/setter pair
- reportedAtUtc ↔ DateTime
-
Time (UTC) of when this positional data was reported
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trueTrack ↔ Azimuth
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → FlightLocationContract? -
Returns a new FlightLocationContract instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< FlightLocationContract> -
mapFromJson(
dynamic json) → Map< String, FlightLocationContract> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< FlightLocationContract> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.