ModelFlightTimeEnum class
Models of calculating the flight time.
Possible values:
- 0 - Standard: Standard model of calculation which takes into account the great circle distance and the average speed of all aircraft typically operating on those distances.
- 1 - ML01: Experimental machine learning (ML) model, which attempts to provide more accurate prediction of the flight time by taking into account the history of flights on specified route and aircraft type within the recent year. This may come in handy in case when on certain routes flights take significant detours due to extended airspace closures dictated by war conflicts, sanction regulations, etc. This can result in significantly increased flight times comparing to regular estimations. Or, some routes generally experience longer delays than other routes of the same distance. This model attempts to take such factors into account and reflect it in the prediction. If a model cannot be applied due to lack of historical and/or aircraft data or prediction is too off set, it automatically fallbacks to
Standard.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
dynamic value) → ModelFlightTimeEnum? -
listFromJson(
dynamic json, {bool growable = false}) → List< ModelFlightTimeEnum>
Constants
- mL01 → const ModelFlightTimeEnum
- standard → const ModelFlightTimeEnum
-
values
→ const List<
ModelFlightTimeEnum> - List of all possible values in this ModelFlightTimeEnum.