RunwayContract class
Constructors
- RunwayContract({required String name, required double trueHdg, required bool isClosed, required SurfaceType surface, RunwayContractLength? length, RunwayContractWidth? width, RunwayContractLocation? location, RunwayContractDisplacedThreshold? displacedThreshold, bool? hasLighting})
- Returns a new RunwayContract instance.
Properties
- displacedThreshold ↔ RunwayContractDisplacedThreshold?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- hasLighting ↔ bool?
-
Does runway has lights
getter/setter pair
- isClosed ↔ bool
-
Marker, if runway is closed
getter/setter pair
- length ↔ RunwayContractLength?
-
getter/setter pair
- location ↔ RunwayContractLocation?
-
getter/setter pair
- name ↔ String
-
Name of the runway. E.g.: 27L, 06, 36C, etc.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- surface ↔ SurfaceType
-
getter/setter pair
- trueHdg ↔ double
-
True heading of the runway in degrees
getter/setter pair
- width ↔ RunwayContractWidth?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → RunwayContract? -
Returns a new RunwayContract instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< RunwayContract> -
mapFromJson(
dynamic json) → Map< String, RunwayContract> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< RunwayContract> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.