getAllAirportDelaysWithHttpInfo method
Global delays (current or historical moment) TIER 3
What is the current or historical delay situation in all airports? or What is the delay index of all airports globally right now or at a moment in past? Please read more about airport delays on here: https://aerodatabox.com/api-airport-delays/ Returns: Statistical delay information about delays (median delay, delay index, cancelled flights) of arrivals and departures for all known airports, represented by a collection of items sorted by the average of arrival and departure index, descending order (from worst to best). Only qualifying and recent enough delay statistics records are returned.
Note: This method returns the HTTP Response.
Parameters:
- DateTime dateUtc: The moment of time for / from which delay data is requested (UTC time, format: YYYY-MM-DDTHH:mm). Default - current time.
Implementation
Future<Response> getAllAirportDelaysWithHttpInfo({
DateTime? dateUtc,
}) async {
// ignore: prefer_const_declarations
final path = r'/airports/delays/{dateUtc}'
.replaceAll('{dateUtc}', dateUtc.toString());
// ignore: prefer_final_locals
Object? postBody;
final queryParams = <QueryParam>[];
final headerParams = <String, String>{};
final formParams = <String, String>{};
const contentTypes = <String>[];
return apiClient.invokeAPI(
path,
'GET',
queryParams,
postBody,
headerParams,
formParams,
contentTypes.isEmpty ? null : contentTypes.first,
);
}