StringListingAirportContractSearchResultCollectionContract class

Properties

count int
The number of items in the collection
getter/setter pair
hashCode int
The hash code for this object.
no setteroverride
items List<ListingAirportContract>
The collection of items
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchBy String
Search parameter used to find the result. Please note, it may be different from the actual input provided!
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

requiredKeys → const Set<String>
The list of required keys that must be present in a JSON.