SubscriptionContract class
Constructors
- SubscriptionContract({required String id, required bool isActive, required DateTime createdOnUtc, required SubscriptionSubjectContract subject, required SubscriberContract subscriber, DateTime? activateBeforeUtc, DateTime? expiresOnUtc})
- Returns a new SubscriptionContract instance.
Properties
- activateBeforeUtc ↔ DateTime?
-
Time (UTC) before which subscription must be activated (may be applicable to some non-active newly created subscriptions)
getter/setter pair
- createdOnUtc ↔ DateTime
-
Time (UTC) when subscription was created
getter/setter pair
- expiresOnUtc ↔ DateTime?
-
Time (UTC) when subscription expires and will be removed. If not specified, subscription never expires.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setteroverride
- id ↔ String
-
Identifier of a subscription. Use this ID to control the subscription in future (e.g. update or delete).
getter/setter pair
- isActive ↔ bool
-
Specifies if the subscription is active
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subject ↔ SubscriptionSubjectContract
-
getter/setter pair
- subscriber ↔ SubscriberContract
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Static Methods
-
fromJson(
dynamic value) → SubscriptionContract? -
Returns a new SubscriptionContract instance and imports its values from
valueif it's a Map, null otherwise. -
listFromJson(
dynamic json, {bool growable = false}) → List< SubscriptionContract> -
mapFromJson(
dynamic json) → Map< String, SubscriptionContract> -
mapListFromJson(
dynamic json, {bool growable = false}) → Map< String, List< SubscriptionContract> >
Constants
-
requiredKeys
→ const Set<
String> - The list of required keys that must be present in a JSON.